# Test Function Coverage Analysis

JavaScript Files: 31
Python Files: 31
JavaScript Tests: 96
Python Tests: 100
Matched Tests: 96
Overall Coverage: 100.00%

## File Coverage

| JavaScript File | Python File | JS Tests | PY Tests | Matched | Coverage | Status |
|----------------|------------|----------|----------|---------|----------|--------|
| class-utils.test.ts | test_class_utils.py | - | - | - | - | Error: JavaScript file not found: js-source/tailwind-merge-v3/tests/class-utils.test.ts |
| core-concepts.test.ts | test_core_concepts.py | - | - | - | - | Error: JavaScript file not found: js-source/tailwind-merge-v3/tests/core-concepts.test.ts |
| extending-theme.test.ts | test_extending_theme.py | - | - | - | - | Error: JavaScript file not found: js-source/tailwind-merge-v3/tests/extending-theme.test.ts |
| merge-classlist.test.ts | test_merge_classlist.py | - | - | - | - | Error: JavaScript file not found: js-source/tailwind-merge-v3/tests/merge-classlist.test.ts |
| arbitrary-properties.test.ts | test_arbitrary_properties.py | 4 | 4 | 4 | 100.00% | Complete |
| arbitrary-values.test.ts | test_arbitrary_values.py | 5 | 5 | 5 | 100.00% | Complete |
| arbitrary-variants.test.ts | test_arbitrary_variants.py | 7 | 7 | 7 | 100.00% | Complete |
| class-group-conflicts.test.ts | test_class_group_conflicts.py | 2 | 2 | 2 | 100.00% | Complete |
| class-map.test.ts | test_class_map.py | 1 | 1 | 1 | 100.00% | Complete |
| colors.test.ts | test_colors.py | 1 | 1 | 1 | 100.00% | Complete |
| conflicts-across-class-groups.test.ts | test_conflicts_across_class_groups.py | 4 | 4 | 4 | 100.00% | Complete |
| content-utilities.test.ts | test_content_utilities.py | 1 | 1 | 1 | 100.00% | Complete |
| create-tailwind-merge.test.ts | test_create_tailwind_merge.py | 2 | 2 | 2 | 100.00% | Complete |
| default-config.test.ts | test_default_config.py | 1 | 1 | 1 | 100.00% | Complete |
| docs-examples.test.ts | test_docs_examples.py | 1 | 1 | 1 | 100.00% | Complete |
| experimental-parse-class-name.test.ts | test_experimental_parse_class_name.py | 3 | 3 | 3 | 100.00% | Complete |
| extend-tailwind-merge.test.ts | test_extend_tailwind_merge.py | 4 | 4 | 4 | 100.00% | Complete |
| important-modifier.test.ts | test_important_modifier.py | 1 | 1 | 1 | 100.00% | Complete |
| lazy-initialization.test.ts | test_lazy_initialization.py | 1 | 1 | 1 | 100.00% | Complete |
| merge-configs.test.ts | test_merge_configs.py | 1 | 1 | 1 | 100.00% | Complete |
| modifiers.test.ts | test_modifiers.py | 4 | 4 | 4 | 100.00% | Complete |
| negative-values.test.ts | test_negative_values.py | 3 | 3 | 3 | 100.00% | Complete |
| non-conflicting-classes.test.ts | test_non_conflicting_classes.py | 1 | 1 | 1 | 100.00% | Complete |
| non-tailwind-classes.test.ts | test_non_tailwind_classes.py | 1 | 1 | 1 | 100.00% | Complete |
| per-side-border-colors.test.ts | test_per_side_border_colors.py | 1 | 1 | 1 | 100.00% | Complete |
| prefixes.test.ts | test_prefixes.py | 1 | 1 | 1 | 100.00% | Complete |
| pseudo-variants.test.ts | test_pseudo_variants.py | 2 | 2 | 2 | 100.00% | Complete |
| public-api.test.ts | test_public_api.py | 8 | 8 | 8 | 100.00% | Complete |
| standalone-classes.test.ts | test_standalone_classes.py | 1 | 1 | 1 | 100.00% | Complete |
| tailwind-css-versions.test.ts | test_tailwind_css_versions.py | 3 | 3 | 3 | 100.00% | Complete |
| theme.test.ts | test_theme.py | 2 | 2 | 2 | 100.00% | Complete |
| tw-join.test.ts | test_tw_join.py | 5 | 5 | 5 | 100.00% | Complete |
| tw-merge.test.ts | test_tw_merge.py | 1 | 1 | 1 | 100.00% | Complete |
| type-generics.test.ts | test_type_generics.py | 3 | 3 | 3 | 100.00% | Complete |
| validators.test.ts | test_validators.py | 21 | 25 | 21 | 100.00% | Complete |

## Extra Python Tests

These Python tests don't have a direct JavaScript equivalent:

### test_validators.py

| Line | Python Function |
|------|----------------|
| 190 | `test_is_image` |
| 223 | `test_is_length` |
| 286 | `test_is_never` |
| 320 | `test_is_shadow` |
